% this m-file generates the figures of the paper, and performs the statistical tests
% Shyrokau, B., De Winter, J. C. F., Stroosma, O., Dijksterhuis, C., Loof, J., Van Paassen, M. M., & Happee, R. (2017). The effect of steering-system linearity, truck driving experience, and simulator motion on steering of an articulated tractor-semitrailer combination.

clc;clear variables;close all
flag=0;
if flag==1
    [LP,SP,SA,EF]=deal(NaN(8,31,10000));[~,ID]=deal(NaN(8,31));
    prof_drivers={'s02' 's03' 's04' 's05' 's06' 's07' 's08' 's09' 's10' 's11' 's12'};
    uni_drivers={'s17' 's18' 's19' 's20' 's21' 's22' 's23' 's24' 's25' 's26' 's27' 's28' 's29' 's30' 's31' 's32' 's33' 's34' 's35' 's36'};
    drivers=[prof_drivers,uni_drivers];
    for j=1:size(drivers,2)
        name = drivers{j};
        load(strcat(name,'_raw.mat')) % A = F-L, B = F-N, C = M-L, D= M-N
        resnames = {strcat(name,'A1') ... % 1. linear, no motion (F-L)
            strcat(name,'A2') ... % 2. linear, no motion (F-L)
            strcat(name,'B1') ... % 3. non-linear, no motion (F-N)
            strcat(name,'B2') ... % 4. non-linear, no motion (F-N)
            strcat(name,'C1') ... % 5. linear, motion (M-L)
            strcat(name,'C2') ... % 6. linear, motion (M-L)
            strcat(name,'D1') ... % 7. non-linear, motion (M-N)
            strcat(name,'D2')};   % 8. non-linear, motion (M-N)
        if  (strcmp(drivers{j},'s10'))
            resnames{8} = strcat(name,'D1'); % the second repetition of D was missed in the experiment
        end
        if  (strcmp(drivers{j},'s33'))
            resnames{2} = strcat(name,'A1'); %% SIMONA malfunction, no second repetition
            resnames{4} = strcat(name,'B1');
            resnames{6} = strcat(name,'C1');
            resnames{8} = strcat(name,'D1');
        end
        for i=1:8
            log= eval(resnames{i});
            condition = find(log.STS.SegmentNr==31,1,'last')-8064:find(log.STS.SegmentNr==31,1,'last')+196; % cut at end, and count back 330.44 seconds
            ID(i,j)=condition(1); % first index
            LP(i,j,1:length(condition))=log.STS.LatPos(condition);
            SP(i,j,1:length(condition))=log.Steering.Vswa(condition);
            SA(i,j,1:length(condition))=log.Steering.SWA(condition);
            EF(i,j,1:length(condition)) = abs(log.Steering.measTswa(condition)).*abs(log.Steering.SWA(condition));
        end
        for i=1:8;eval(['clear ' resnames{i}]);end
    end
else
    load all_data_journal_paper
end
%% removal of a few specific maneuvers
for i=1:4
    if i==1;a1=3;a2=9;a3=1251:2501;end % very early overtake (pp 9, run 3, overtake 1)
    if i==2;a1=2;a2=11;a3=[3251:3751 6751:7251];end % move to the shoulder (two periods of 20 s each; total 40 seconds)
    if i==3;a1=5;a2=1;a3=7251:8251;end % overtake on the right (pp 1, run 5, overtake 4)
    if i==4;a1=6;a2=11;a3=6876:7251;end % move to the shoulder (one period of 15 seconds)
    LP(a1,a2,a3)=NaN;
    SP(a1,a2,a3)=NaN;
    SA(a1,a2,a3)=NaN;
    EF(a1,a2,a3)=NaN;
end
time=0:0.04:0.04*10000-0.04;
%%
[meffort,SRR,signMLP,MLP,SDLP,SWS,TLC_to_left,TLC_to_right,TLC_on_left]=deal(NaN(8,31));
[LCTc,LCTr,LCTt]=deal(NaN(8,31,4));

for j=1:size(ID,2) % loop over 31 participants
    disp(j)
    for i=1:8
        condition2 = 1:8261;
        SAs=squeeze(SA(i,j,condition2));
        SPs=squeeze(SP(i,j,condition2));
        LPs=squeeze(LP(i,j,condition2));
        
        SAsr=SAs;SAsr(isnan(SAsr))=[];
        SPsr=SPs;SPsr(isnan(SPsr))=[];
        
        meffort(i,j) = nanmean(EF(i,j,condition2));
        [~,SRR(i,j)] = get_SteerRev(SAsr,SPsr,3,3); % Steering wheel reversal rate
        SWS(i,j) = steering_wheel_steadiness(SPsr); % Steering wheel steadiness (% of time)
        
        condition3 = (time>=40 & time<=59.12) | (time>=122 & time<=141) | (time >=193 & time<=205) | (time>=260 & time<=276); % lane keeping (not disturbed by lane changes, 260-271.48 is very high radius curve)
        MLP(i,j)  = nanmean(LPs(condition3)); % mean lateral position
        SDLP(i,j) = nanstd(LPs(condition3));  % SDLP
        
        condition_left_corner = (time >= 59.12 & time <= 69) | (time >= 205 & time <= 221); % mean of lateral position with sign reversed depending on the direction of the curve
        condition_right_corner = time <= 22.84; % condition_left_corner and condition_right_corner together form 61 s (In turns (selected 61 seconds of driving in curves, excluding overtaking)
        signMLP(i,j)  = nanmean([-LPs(condition_left_corner); LPs(condition_right_corner)]);
        
        for oo=1:4 % loop over 4 overtakes
            if oo==1
                condition4=time>=68 & time <=104;condition4b= time>=104 & time <=121;
            elseif oo==2
                condition4=time>=140 & time <=174;condition4b= time>=174 & time <=191;
            elseif oo==3
                condition4=time>=220 & time <=243;condition4b= time>=243 & time <=260;
            elseif oo==4
                condition4=time>=275 & time <=310;condition4b= time>=310 & time <=327;
            end
            try
                LCTc(i,j,oo)=  find(LPs(condition4)>2.75,1,'first')/25  - find(LPs(condition4)<=0.75,1,'last')/25; % Changing to left lane time
                LCTr(i,j,oo)=  find(LPs(condition4b)<0.75,1,'first')/25 - find(LPs(condition4b)>=2.75,1,'last')/25; % Returning to right lane time
                LCTt(i,j,oo)=  -(-1+find(condition4,1,'first')+find(LPs(condition4)>2.75,1,'first'))/25  + (-1+find(condition4b,1,'first')+find(LPs(condition4b)>=2.75,1,'last'))/25; % Mean time on left lane
            catch error
            end
            
        end
        TLC_to_left(i,j)=nanmean(LCTc(i,j,:));
        TLC_to_right(i,j)=nanmean(LCTr(i,j,:));
        TLC_on_left(i,j)=nanmean(LCTt(i,j,:));
    end
end
%% figure with mean lateral position for no motion vs. motion
figure;hold on
plot(time,squeeze(nanmean(nanmean((LP(1:4,:,:))))),'k:','Linewidth',2)
plot(time,squeeze(nanmean(nanmean((LP(5:8,:,:))))),'r','Linewidth',2)
curveboundaries
plot([0 350],[0 0],'k')
legend('No motion','Motion','location','southeast')
xlabel('Time (s)')
ylabel('Right \leftarrow Lateral position (m) \rightarrow Left')
set(gca,'pos',[0.0879861125267214 0.1303546110704436 0.854461803723954 0.825283686231214],'xlim',[0 337.4],'ylim',[-1 1],'LooseInset', [0.01 0.01 0.01 0.01])
box on
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
set(gcf,'PaperPositionMode','manual','paperunits','inches','PaperPosition',[0 0 15 5]);
%% figure with mean lateral position for truck drivers and university drivers
figure;hold on
plot(time,squeeze(nanmean(nanmean(LP(1:8,1:11,:)))),'k:','Linewidth',2) % truck drivers
plot(time,squeeze(nanmean(nanmean(LP(1:8,12:end,:)))),'r','Linewidth',2) % university drivers
plot([0 350],[0 0],'k')
set(gca,'pos',[0.0879861125267214 0.1303546110704436 0.854461803723954 0.825283686231214]);
curveboundaries
legend('Truck drivers','University drivers','location','Southeast')
set(gca,'xlim',[0 337.4],'ylim',[-5 5],'ytick',-10:10,'LooseInset', [0.01 0.01 0.01 0.01])
box on
xlabel('Time (s)')
ylabel('Right \leftarrow Lateral position (m) \rightarrow Left')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
set(gcf, 'PaperPositionMode', 'manual','paperunits','inches','PaperPosition', [0 0 15 10]);
%% Figure with mean steering effort for the four conditions
figure;hold on
effort_A = 0.5*(nanmean((abs(squeeze(EF(1,:,:))')),2)+nanmean((abs(squeeze(EF(2,:,:))')),2)); % No Motion-Linear
effort_B = 0.5*(nanmean((abs(squeeze(EF(3,:,:))')),2)+nanmean((abs(squeeze(EF(4,:,:))')),2)); % No Motion-Nonlinear
effort_C = 0.5*(nanmean((abs(squeeze(EF(5,:,:))')),2)+nanmean((abs(squeeze(EF(6,:,:))')),2)); % Motion-Linear
effort_D = 0.5*(nanmean((abs(squeeze(EF(7,:,:))')),2)+nanmean((abs(squeeze(EF(8,:,:))')),2)); % Motion-Nonlinear
plot(time,effort_A,'k','Linewidth',2)
plot(time,effort_B,'b','Linewidth',2)
plot(time,effort_C,'-','Linewidth',2,'color',[255 165 0]/255)
plot(time,effort_D,'c','Linewidth',2)
set(gca,'pos',[0.0879861125267214 0.1303546110704436  0.854461803723954 0.825283686231214]);
curveboundaries
legend('No motion-Linear','No motion-Nonlinear','Motion-Linear','Motion-Nonlinear')
set(gca,'xlim',[0 337.4],'ylim',[0 160],'LooseInset', [0.01 0.01 0.01 0.01],'tickdir','out')
box on
xlabel('Time (s)')
ylabel('Mean steering effort (Nm*deg)')
h=rectangle('position',[81.08 0 90.56 15],'facecolor','none','Linewidth',1);
pan on
set(h,'Clipping','off')
plot([115 137.5],[15 73],'k--','Linewidth',1)
ah=axes('position',[.293 .45 .229 .35]);
hold on;box on
plot(time,effort_A,'k','Linewidth',2)
plot(time,effort_B,'b','Linewidth',2)
plot(time,effort_C,'-','Linewidth',2,'color',[255 165 0]/255)
plot(time,effort_D,'c','Linewidth',2)
set(gca,'xlim',[81.08 171.64],'ylim',[0 15],'LooseInset',[0.01 0.01 0.01 0.01],'tickdir','out')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
set(gcf,'PaperPositionMode','manual','paperunits','inches','PaperPosition', [0 0 15 10]);
%% create a matrix obj_data
[meffort_aver,SRR_aver,SWS_aver,SDLP_aver,MLP_aver,signMLP_aver,TLC_to_left_aver,TLC_to_right_aver,TLC_on_left_aver]=deal(NaN(4,31));
label = {'SE    ', 'SRR   ','SWS   ','SDLP  ','MLP   ','MLPtur','LCTc  ','LCTr  ','LCTt  '};
par=1:4:size(label,2)*4;
[m01,m02,m03,m04,sd01,sd02,sd03,sd04,p01,p02,p03,F01,F02,F03,df1_01,df1_02,df1_03,df2_01,df2_02,df2_03,partial_eta_squared_within,partial_eta_squared_interaction,partial_eta_squared_between,TOp,TOdf,TOt,UOp,UOdf,UOt]=deal(NaN(size(par,2),1));
j=1;
for i=1:2:8 % create 4 x 31 matrices per performance measure (1 = No motion-Linear, 2 = No motion-Nonlinear, 3 = Motion-Linear, 4 = Motion-Nonlinear)
    
    meffort_aver(j,:)      = mean([meffort(i,:)'      meffort(i+1,:)'],2);
    SRR_aver(j,:)          = mean([SRR(i,:)'          SRR(i+1,:)'],2);
    SWS_aver(j,:)          = mean([SWS(i,:)'          SWS(i+1,:)'],2);
    SDLP_aver(j,:)         = mean([SDLP(i,:)'         SDLP(i+1,:)'],2);
    MLP_aver(j,:)          = mean([MLP(i,:)'          MLP(i+1,:)'],2);
    signMLP_aver(j,:)      = mean([signMLP(i,:)'      signMLP(i+1,:)'],2);
    TLC_to_left_aver(j,:)  = mean([TLC_to_left(i,:)'  TLC_to_left(i+1,:)'],2);
    TLC_to_right_aver(j,:) = mean([TLC_to_right(i,:)' TLC_to_right(i+1,:)'],2);
    TLC_on_left_aver(j,:)  = mean([TLC_on_left(i,:)'  TLC_on_left(i+1,:)'],2);
    j=j+1;
end
obj_data = [meffort_aver' SRR_aver' SWS_aver' SDLP_aver' MLP_aver' signMLP_aver' TLC_to_left_aver' TLC_to_right_aver' TLC_on_left_aver']; % create 31 x 36 matrix (31 participants x (9 measures * 4 conditions per measure))

[M_Truck,SD_Truck]=deal(NaN(size(par,2),4));
[F_Truck,p_Truck]=deal(NaN(size(par,2),3));
[partial_eta_squared_motion_Truck,partial_eta_squared_steering_Truck,partial_eta_squared_motion_steering_interaction_Truck]=deal(NaN(size(par,2),1));
for i=1:size(par,2)
    index = par(i);
    table=rm_anova2([obj_data(1:11,index);obj_data(1:11,index+1);obj_data(1:11,index+2);obj_data(1:11,index+3)],...
        repmat(transpose(1:11),4,1), [ones(22,1);2*ones(22,1)], [ones(11,1);2*ones(11,1);ones(11,1);2*ones(11,1)],{'motion','steering'}); % motion, steering
    M_Truck(i,:)=mean(obj_data(1:11,index:index+3));
    SD_Truck(i,:)=std(obj_data(1:11,index:index+3));
    F_Truck(i,:)=cell2mat(table(2:4,5));
    p_Truck(i,:)=cell2mat(table(2:4,6));
    partial_eta_squared_motion_Truck(i)=cell2mat(table(2,2))  /sum(cell2mat(table([2 5],2)));
    partial_eta_squared_steering_Truck(i)=cell2mat(table(3,2))/sum(cell2mat(table([3 6],2)));
    partial_eta_squared_motion_steering_interaction_Truck(i)=cell2mat(table(4,2))/sum(cell2mat(table([4 7],2)));
end


disp(' ')
disp('Two-way repeated measures ANOVA for truck drivers only (n = 11)')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[M_Truck(i,1) SD_Truck(i,1) M_Truck(i,2) SD_Truck(i,2) M_Truck(i,3) SD_Truck(i,3) M_Truck(i,4) SD_Truck(i,4)])...
        sprintf('%8.2f',F_Truck(i,1))  sprintf('%8.3f',p_Truck(i,1)) sprintf('%8.3f',partial_eta_squared_motion_Truck(i))...
        sprintf('%8.2f',F_Truck(i,2))  sprintf('%8.3f',p_Truck(i,2)) sprintf('%8.3f',partial_eta_squared_steering_Truck(i))...
        sprintf('%8.2f',F_Truck(i,3))  sprintf('%8.3f',p_Truck(i,3)) sprintf('%8.3f',partial_eta_squared_motion_steering_interaction_Truck(i))...
        ])
end

%%
[M_Truck,SD_Truck]=deal(NaN(size(par,2),4));
[F_Truck,p_Truck]=deal(NaN(size(par,2),3));
[partial_eta_squared_motion_Truck,partial_eta_squared_steering_Truck,partial_eta_squared_motion_steering_interaction_Truck]=deal(NaN(size(par,2),1));
for i=1:size(par,2)
    index = par(i);
    table=rm_anova2([obj_data(12:end,index);obj_data(12:end,index+1);obj_data(12:end,index+2);obj_data(12:end,index+3)],...
        repmat(transpose(1:20),4,1), [ones(40,1);2*ones(40,1)], [ones(20,1);2*ones(20,1);ones(20,1);2*ones(20,1)],{'motion','steering'}); % motion, steering
    M_Truck(i,:)=mean(obj_data(1:20,index:index+3));
    SD_Truck(i,:)=std(obj_data(1:20,index:index+3));
    F_Truck(i,:)=cell2mat(table(2:4,5));
    p_Truck(i,:)=cell2mat(table(2:4,6));
    partial_eta_squared_motion_Truck(i)=cell2mat(table(2,2))  /sum(cell2mat(table([2 5],2)));
    partial_eta_squared_steering_Truck(i)=cell2mat(table(3,2))/sum(cell2mat(table([3 6],2)));
    partial_eta_squared_motion_steering_interaction_Truck(i)=cell2mat(table(4,2))/sum(cell2mat(table([4 7],2)));
end


disp(' ')
disp('Two-way repeated measures ANOVA for university drivers only (n = 20)')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[M_Truck(i,1) SD_Truck(i,1) M_Truck(i,2) SD_Truck(i,2) M_Truck(i,3) SD_Truck(i,3) M_Truck(i,4) SD_Truck(i,4)])...
        sprintf('%8.2f',F_Truck(i,1))  sprintf('%8.3f',p_Truck(i,1)) sprintf('%8.3f',partial_eta_squared_motion_Truck(i))...
        sprintf('%8.2f',F_Truck(i,2))  sprintf('%8.3f',p_Truck(i,2)) sprintf('%8.3f',partial_eta_squared_steering_Truck(i))...
        sprintf('%8.2f',F_Truck(i,3))  sprintf('%8.3f',p_Truck(i,3)) sprintf('%8.3f',partial_eta_squared_motion_steering_interaction_Truck(i))...
        ])
end
%% ANOVA table for linear vs. nonlinear steering model
for i=1:size(par,2)
    index = par(i);
    Data  = [nanmean(obj_data(:,[index index+2]),2); nanmean(obj_data(:,[index+1 index+3]),2)]; % index & index+2 = linear, index+1 & index+3 = nonlinear
    Group = repmat( [ones(1,11) 2*ones(1,20);],1,2)'; % group (1 = truck driver, 2 = university driver)
    SM    = [ones(31,1); 2*ones(31,1)]; % steering system (1 = linear, 2 = nonlinear)
    PPG  = repmat(1:31,1,2)'; % participant number
    X    = [Data Group SM PPG];
    [~,p,~,stats]=ttest(X(X(:,2)==1 & X(:,3)==1,1),X(X(:,2)==1 & X(:,3)==2,1));TOp(i)=p;TOdf(i)=stats.df;TOt(i)=stats.tstat; % paired t test for truck drivers only
    [~,p,~,stats]=ttest(X(X(:,2)==2 & X(:,3)==1,1),X(X(:,2)==2 & X(:,3)==2,1));UOp(i)=p;UOdf(i)=stats.df;UOt(i)=stats.tstat; % paired t test for university drivers only
    %X(:,1)=tiedrank(X(:,1));
    pause
    [anova_SSQ,anova_df,anova_MSQ,anova_F,anova_p]=mixed_between_within_anova(X,1); % 1 = between-subjects factor, 2 = between-subjects error, 3 = within-subjects factor, 4 = within x between interaction, 5 = within-subjects error
    
    partial_eta_squared_within(i)=cell2mat(anova_SSQ(3))/sum(cell2mat(anova_SSQ([3 5])));
    partial_eta_squared_interaction(i)=cell2mat(anova_SSQ(4))/sum(cell2mat(anova_SSQ([4 5])));
    partial_eta_squared_between(i)=cell2mat(anova_SSQ(1))/sum(cell2mat(anova_SSQ([1 2])));
    
    m01(i,:)  = mean(X( X(:,2)==1 & X(:,3)==1,1));
    sd01(i,:) = std(X( X(:,2)==1 & X(:,3)==1,1));
    m02(i,:)  = mean(X(X(:,2)==1 & X(:,3)==2,1));
    sd02(i,:) = std(X(X(:,2)==1 & X(:,3)==2,1));
    m03(i,:)  = mean(X( X(:,2)==2 & X(:,3)==1,1));
    sd03(i,:) = std(X( X(:,2)==2 & X(:,3)==1,1));
    m04(i,:)  = mean(X(X(:,2)==2 & X(:,3)==2,1));
    sd04(i,:) = std(X(X(:,2)==2 & X(:,3)==2,1));
    
    F01(i,:)    = cell2mat(anova_F(3));
    df1_01(i,:) = cell2mat(anova_df(3));
    df2_01(i,:) = cell2mat(anova_df(5));
    p01(i,:)    = cell2mat(anova_p(3));
    
    F02(i,:)    = cell2mat(anova_F(1));
    df1_02(i,:) = cell2mat(anova_df(1));
    df2_02(i,:) = cell2mat(anova_df(2));
    p02(i,:)    = cell2mat(anova_p(1));
    
    F03(i,:)    = cell2mat(anova_F(4));
    df1_03(i,:) = cell2mat(anova_df(4));
    df2_03(i,:) = cell2mat(anova_df(5));
    p03(i,:)    = cell2mat(anova_p(4));
end
disp(' ')
disp('Linear vs. nonlinear steering system model')
disp('Par      Truck_L         Truck_N         Stud_L          Stud_N         Effect of Steering system            Effect of group                      Interaction')
disp('           M       SD      M       SD      M       SD      M       SD      F       df1  df2   p      eta_2     F      df1  df2    p      eta_2     F      df1  df2    p      eta_2')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i) m03(i) sd03(i) m04(i) sd04(i) F01(i)]) sprintf('%6.0f',[df1_01(i) df2_01(i)]) sprintf('%8.4f',p01(i)) sprintf('%8.3f',partial_eta_squared_within(i)) ...
        sprintf('%8.2f',F02(i)) sprintf('%6.0f',[df1_02(i) df2_02(i)]) sprintf('%8.3f',p02(i)) sprintf('%8.3f',partial_eta_squared_between(i)) ...
        sprintf('%8.2f',F03(i)) sprintf('%6.0f',[df1_03(i) df2_03(i)]) sprintf('%8.3f',p03(i)) sprintf('%8.3f',partial_eta_squared_interaction(i))] )
end

disp(' ')
disp('Linear vs. nonlinear steering system model for truck drivers only')
disp('Par      Truck_L         Truck_N         Effect of Steering system      ')
disp('           M       SD      M       SD     df   p      t')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i)]) sprintf('%6.0f',TOdf(i))  sprintf('%8.3f',TOp(i)) ...
        sprintf('%8.2f',TOt(i)) ] )
end

disp(' ')
disp('Linear vs. nonlinear steering system model for university drivers only')
disp('Par      Truck_L         Truck_N         Effect of Steering system      ')
disp('           M       SD      M       SD     df   p      t')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m03(i) sd03(i) m04(i) sd04(i)]) sprintf('%6.0f',UOdf(i))  sprintf('%8.3f',UOp(i)) ...
        sprintf('%8.2f',UOt(i)) ] )
end
%% ANOVA table for motion on vs. motion off
[m01,m02,m03,m04,sd01,sd02,sd03,sd04,p01,p02,p03,F01,F02,F03,df1_01,df1_02,df1_03,df2_01,df2_02,df2_03,partial_eta_squared_within,partial_eta_squared_interaction,partial_eta_squared_between,TOp,TOdf,TOt,UOp,UOdf,UOt]=deal(NaN(size(par,2),1));

disp(' ')
disp('Motion Off vs. Motion On')
for i=1:size(par,2)
    index = par(i);
    Data  = [nanmean(obj_data(:,[index index+1]),2); nanmean(obj_data(:,[index+2 index+3]),2)]; % tested variable
    Group = repmat( [ones(1,11) 2*ones(1,20);],1,2)'; % 1 = Truck drivers, 2 = University drivers
    SM    = [ones(31,1); 2*ones(31,1)]; % motion condition
    PPG  = repmat(1:31,1,2)'; % participant number
    X    = [Data Group SM PPG];
    [~,p,~,stats]=ttest(X(X(:,2)==1 & X(:,3)==1,1),X(X(:,2)==1 & X(:,3)==2,1));TOp(i)=p;TOdf(i)=stats.df;TOt(i)=stats.tstat; % paired t test for truck drivers only
    [~,p,~,stats]=ttest(X(X(:,2)==2 & X(:,3)==1,1),X(X(:,2)==2 & X(:,3)==2,1));UOp(i)=p;UOdf(i)=stats.df;UOt(i)=stats.tstat; % paired t test for university drivers only
    
    %X(:,1)=tiedrank(X(:,1));
    [anova_SSQ,anova_df,anova_MSQ,anova_F,anova_p]=mixed_between_within_anova(X,1); % 1 = between-subjects factor, 2 = between-subjects factor, 3 = within-subjects factor, 4 = within x between interaction, 5 = within-subjects error
    
    partial_eta_squared_within(i)=cell2mat(anova_SSQ(3))/sum(cell2mat(anova_SSQ([3 5])));
    partial_eta_squared_interaction(i)=cell2mat(anova_SSQ(4))/sum(cell2mat(anova_SSQ([4 5])));
    partial_eta_squared_between(i)=cell2mat(anova_SSQ(1))/sum(cell2mat(anova_SSQ([1 2])));
    
    m01(i,:)  = mean(X(X(:,2)==1 & X(:,3)==1,1));
    sd01(i,:) = std(X(X(:,2)==1 & X(:,3)==1,1));
    m02(i,:)  = mean(X(X(:,2)==1 & X(:,3)==2,1));
    sd02(i,:) = std(X(X(:,2)==1 & X(:,3)==2,1));
    m03(i,:)  = mean(X(X(:,2)==2 & X(:,3)==1,1));
    sd03(i,:) = std(X(X(:,2)==2 & X(:,3)==1,1));
    m04(i,:)  = mean(X(X(:,2)==2 & X(:,3)==2,1));
    sd04(i,:) = std(X(X(:,2)==2 & X(:,3)==2,1));
    
    F01(i,:)    = cell2mat(anova_F(3));
    df1_01(i,:) = cell2mat(anova_df(3));
    df2_01(i,:) = cell2mat(anova_df(5));
    p01(i,:)    = cell2mat(anova_p(3));
    
    F02(i,:)    = cell2mat(anova_F(1));
    df1_02(i,:) = cell2mat(anova_df(1));
    df2_02(i,:) = cell2mat(anova_df(2));
    p02(i,:)    = cell2mat(anova_p(1));
    
    F03(i,:)    = cell2mat(anova_F(4));
    df1_03(i,:) = cell2mat(anova_df(4));
    df2_03(i,:) = cell2mat(anova_df(5));
    p03(i,:)    = cell2mat(anova_p(4));
end

disp('Par      Truck_NM        Truck_M         Stud_NM         Stud_M          Effect of Motion Condition         Effect of group                        Interaction')
disp('           M       SD      M       SD      M       SD      M       SD      F       df1  df2   p      eta_2     F      df1  df2    p      eta_2     F      df1  df2    p      eta_2')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i) m03(i) sd03(i) m04(i) sd04(i) F01(i)]) sprintf('%6.0f',[df1_01(i) df2_01(i)]) sprintf('%8.3f',p01(i)) sprintf('%8.3f',partial_eta_squared_within(i)) ...
        sprintf('%8.2f',F02(i)) sprintf('%6.0f',[df1_02(i) df2_02(i)]) sprintf('%8.3f',p02(i)) sprintf('%8.3f',partial_eta_squared_between(i)) ...
        sprintf('%8.2f',F03(i)) sprintf('%6.0f',[df1_03(i) df2_03(i)]) sprintf('%8.3f',p03(i)) sprintf('%8.3f',partial_eta_squared_interaction(i))] )
end

disp(' ')
disp('No Motion vs. Motion for truck drivers only')
disp('Par      Truck_NM        Truck_M         Effect of Motion      ')
disp('           M       SD      M       SD     df   p      t')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i)]) sprintf('%6.0f',TOdf(i))  sprintf('%8.3f',TOp(i)) ...
        sprintf('%8.2f',TOt(i)) ] )
end

disp(' ')
disp('No Motion vs. Motion for university drivers only')
disp('Par      Truck_NM        Truck_M         Effect of Motion      ')
disp('           M       SD      M       SD     df   p      t')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m03(i) sd03(i) m04(i) sd04(i)]) sprintf('%6.0f',UOdf(i))  sprintf('%8.3f',UOp(i)) ...
        sprintf('%8.2f',UOt(i)) ] )
end
%%
PP=22;C=6; %% p22 is 's27', condition 6 is C2 (linear, motion (M-L))
if flag==1
    load('s27_raw.mat') % log files of Simona (@ 25 Hz)
    load('s27_C2_01_03_2016_17_23_55_motion.mat'); % UT and Y matrices U @ 25 Hz, Y @ 100 Hz
    x25=UT(ID(C,PP):end,1)  -min(UT(ID(C,PP):end,1));
    x100=0:0.01:length(Y)/100-min(UT(ID(C,PP):end,1));
    gvt=UT(ID(C,PP):end,6)-mean(UT(3200:4150,6)); % offset correction (based on a the straight road segment)
    gsc=(Y( 4*ID(C,PP)-4:end,5)-mean(Y(13000:16500,5))); % offset correction (based on a straight road segment)
    lp=squeeze(LP(C,PP,1:length(x25)));
    save('all_data_journal_paper','LP','SP','SA','EF','ID','x25','x100','gvt','gsc','lp');
end
figure;hold on;
yyaxis left
plot(x25,gvt,'k-','Linewidth',2) % g-force virtual truck cabin
plot(x100,gsc,'-','Linewidth',3','color',[.8 .8 .8]) % g-force simulator cabin @ 100 Hz
set(gca,'ylim',[-2 2],'xlim',[0 330.4])
ylabel('g-force (m/s^2)')
ax=gca;ax.YColor=[0 0 0];
yyaxis right
plot(x25,lp,'r:','Linewidth',2) % Lateral position of the truck on the road
ax = gca;ax.YColor=[1 0 0];
curveboundaries
xlabel('Time (s)')
ylabel('Right \leftarrow Lateral position (m) \rightarrow Left')
legend('g-force virtual truck cabin','g-force simulator cabin','Lateral position','location','south')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
set(gcf,'PaperPositionMode', 'manual','paperunits','inches','PaperPosition', [0 0 15 10]);
set(gca,'LooseInset', [0.01 0.01 0.01 0.01],'pos',[0.0879861125267214 0.1303546110704436 0.854461803723954 0.825283686231214],'xlim',[0 330.4],'ylim',[-5 5],'ytick',-5:1:5);
