% this m-file performs the statistical tests for the self-report data
clc;clear variables;close all %#ok<*CLALL>
MM=2; % if MM=1 then steering, if MM=2 then motion
qdata = xlsread('questionnairedata.xlsx' ,'readinmatlab'); % 32 x 304 matrix
[~,qsched] = xlsread('questionnairedata.xlsx','Schedule'); % 32 x 8 matrix indicating the schedule of participants
%% replace letters by numbers and get sorting index
cons = {'A','B','C','D'};
for i=1:32 % loop over participants
    cnt=0;
    for k=1:4
        temp = strcmp(qsched(i,:),cons{k});
        temp = find(temp);
        for j=temp
            cnt=cnt+1;
            qsched{i,j}=cnt;
        end
    end
end
qsched = cell2mat(qsched);
[~,index] = sort(qsched,2);
%% rearrange qdata to 3 dimensions. dim1 = 32 participants,dim2 = 8 rudes,dim3 = 38 questions
qdata3 = zeros(32,8,38);
for i = 1:size(qdata3,1)
    cnt=0;
    for j=1:size(qdata3,3):size(qdata,2)
        cnt=cnt+1;
        qdata3(i,cnt,:)=qdata(i,j:j+size(qdata3,3)-1);
    end
end
%% resort datamatrix
for i= 1:32 % loop over participants
    qdata3(i,:,:) = qdata3(i,index(i,:),:);
end
%% return to a 2d matrix  (dim1=32 participants, dim2=304 questions)
[d1,d2]=size(qdata);
sortdata=NaN(d1,d2); % 32 x 304 empty matrix
for i=1:32
    cnt=0;
    for j=1:size(qdata3,3):size(qdata,2) % 1,39,77,115,153,191,229,267 (38 questions per condition)
        cnt=cnt+1;
        sortdata(i,j:j+size(qdata3,3)-1)=qdata3(i,cnt,:);
    end
end
%% replacing missing values with NaN
sortdata(sortdata==-99999)=nan;
%%
cnt=0;
for i=15:size(qdata3,3):size(qdata,2) % 15, 53, 91, 129, 167, 205, 243, 281 (start indexes of the 9-item Van der Laan questionnaire)
    cnt=cnt+1;
    sortdata(:,i:i+8)=sortdata(:,i:i+8)-3; % rerange (in the Excel file it runs from 1 to 5. now from -2 to +2)
    sortdata(:,[i+2 i+5 i+7])= sortdata(:,[i+2 i+5 i+7])*-1; % mirror items 3, 6, 8; now all 9 items run from -2 = positive, to +2 = negative
    for j=1:2
        if j==1
            X=sortdata(:,[i i+2 i+4 i+6 i+8]); % 5 usefulness variables
        elseif j==2
            X=sortdata(:,[i+1 i+3 i+5 i+7]); % 4 satisfaction variables
        end
        X(X==3)=2; % correct coding error
        X=-X; % reverse, so that 2 = positive, -2 = negative
        sortdata(:,i-3+j)=mean(X,2);
    end
end
%% sort by question
temp=NaN(size(sortdata));
include=1:size(qdata3,3):size(qdata,2); %1, 39, 77, 115, 153, 191, 229, 267
cnt=0;
for i = 1:8:size(sortdata,2) %nr of questions per ride=38, 8 rides in total
    temp(:,i:i+7) = sortdata(:,include+cnt);
    cnt=cnt+1;
end
sortdata=temp;
%% collapse conditions (1 & 2) (columns 305:456 in sortdata)
cnt=0;
n=size(sortdata,2);
for i=1:2:n % size data
    cnt=cnt+1;
    sortdata(:,n+cnt)=nanmean(sortdata(:,i:i+1),2);
end
%% calculate fixed (A+B) vs moving (C+D) (38*2 items, columns 457-532 in sortdata)
n2 = size(sortdata,2);
cnt=0;
for i=n+1:2:n2
    cnt=cnt+1;
    sortdata(:,n2+cnt)=mean(sortdata(:,i:i+1),2);
end
%% calculate linear (A+C) vs nonlinear (B+D) (38*2 items, columns 533-608 in sortdata)
n3 = size(sortdata,2);
for i=n+1:4:n2
    sortdata(:,end+1)= mean(sortdata(:,i:i+2),2); %#ok<SAGROW>   % Linear
    sortdata(:,end+1)= mean(sortdata(:,i+1:i+3),2); %#ok<SAGROW> % Nonlinear
end
%%
index = [309 313 317 321 325 329 333 337 341 345 349 397 401 405 409 413 417 421];
y_names = {'Difficulty' 'Risk' 'Mental Effort' 'Physical Effort' ...
    'Safety' 'Realistic driving' 'Comfort' 'Realistic response' 'Easiness' 'Tight steering' 'Course stability'...
    'Vehicle  stability' 'Play' 'Required Torque' 'Jerk' 'Sensitivity' 'Returnability' 'Vehicle response'};

PCA_data = [sortdata(:,index); sortdata(:,index+1); sortdata(:,index+2); sortdata(:,index+3)]; % 128 (32 participants * 4 runs) x 18 matrix
lding= pca_j(corr(PCA_data),1);
pc_scores = zscore(PCA_data)/lding';
data_after_pca = [pc_scores(1:32), pc_scores(33:64), pc_scores(65:96), pc_scores(97:128)]; % 32 x 4 matrix
%% ANOVA
Group = repmat( [ones(1,12) 2*ones(1,20);],1,2)'; %
SM    = [ones(32,1); 2*ones(32,1)]; % variant: steering system  / motion on-off
PPG  = repmat(1:32,1,2)';           % number of participant
%
if MM==1
    Data_Steering  = [nanmean(data_after_pca(:,[1 3]),2); nanmean(data_after_pca(:,[2 4]),2)]; % Linear, Nonlinar
    X=[Data_Steering Group SM PPG];
elseif MM==2
    Data_Motion    = [nanmean(data_after_pca(:,[1 2]),2); nanmean(data_after_pca(:,[3 4]),2)]; % Fixed, Motion
    X=[Data_Motion Group SM PPG];
end

X(isnan(X(:,1)),:)=[];
X(:,1)=tiedrank(X(:,1));

i=1;
[~,p,~,stats]=ttest(X(X(:,2)==1 & X(:,3)==1,1),X(X(:,2)==1 & X(:,3)==2,1));TOp(i)=p;TOdf(i)=stats.df;TOt(i)=stats.tstat; % paired t test for truck drivers only
[~,p,~,stats]=ttest(X(X(:,2)==2 & X(:,3)==1,1),X(X(:,2)==2 & X(:,3)==2,1));UOp(i)=p;UOdf(i)=stats.df;UOt(i)=stats.tstat; % paired t test for university drivers only
[anova_SSQ,anova_df,anova_MSQ,anova_F,anova_p]=mixed_between_within_anova(X,1); % 1 = between-subjects factor, 2 = between-subjects factor, 3 = within-subjects factor, 4 = within x between interaction, 5 = within-subjects error

i=1;
partial_eta_squared_within(i)=cell2mat(anova_SSQ(3))/sum(cell2mat(anova_SSQ([3 5])));
partial_eta_squared_interaction(i)=cell2mat(anova_SSQ(4))/sum(cell2mat(anova_SSQ([4 5])));
partial_eta_squared_between(i)=cell2mat(anova_SSQ(1))/sum(cell2mat(anova_SSQ([1 2])));

m01(i,:)  = nanmean(X( X(:,2)==1 & X(:,3)==1,1));
sd01(i,:) = std(X( X(:,2)==1 & X(:,3)==1,1));
m02(i,:)  = nanmean(X(X(:,2)==1 & X(:,3)==2,1));
sd02(i,:) = std(X(X(:,2)==1 & X(:,3)==2,1));
m03(i,:)  = nanmean(X( X(:,2)==2 & X(:,3)==1,1));
sd03(i,:) = std(X( X(:,2)==2 & X(:,3)==1,1));
m04(i,:)  = nanmean(X(X(:,2)==2 & X(:,3)==2,1));
sd04(i,:) = std(X(X(:,2)==2 & X(:,3)==2,1));

F01(i,:)    = cell2mat(anova_F(3));
df1_01(i,:) = cell2mat(anova_df(3));
df2_01(i,:) = cell2mat(anova_df(5));
p01(i,:)    = cell2mat(anova_p(3));

F02(i,:)    = cell2mat(anova_F(1));
df1_02(i,:) = cell2mat(anova_df(1));
df2_02(i,:) = cell2mat(anova_df(2));
p02(i,:)    = cell2mat(anova_p(1));

F03(i,:)    = cell2mat(anova_F(4));
df1_03(i,:) = cell2mat(anova_df(4));
df2_03(i,:) = cell2mat(anova_df(5));
p03(i,:)    = cell2mat(anova_p(4));
eta2(i,:)  = NaN;

disp(' ')
disp('Truck drivers only')
disp('Par      Truck_L         Truck_N         Effect of Condition      ')
disp('           M       SD      M       SD    df   p        t')
for i=1
    disp(['PCA  ' sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i)]) sprintf('%6.0f',TOdf(i))  sprintf('%8.3f',TOp(i)) ...
        sprintf('%8.2f',TOt(i)) ] )
end

disp(' ')
disp('University drivers only')
disp('Par      Truck_L         Truck_N         Effect of Condition      ')
disp('           M       SD      M       SD    df   p       t')
for i=1
    disp(['PCA  ' sprintf('%8.2f' ,[m03(i) sd03(i) m04(i) sd04(i)]) sprintf('%6.0f',UOdf(i))  sprintf('%8.3f',UOp(i)) ...
        sprintf('%8.2f',UOt(i)) ] )
end

label = {'1st   '};
disp('Par      Truck_L         Truck_N        Stud_L          Stud_N         Effect of Steering system    Effect of group             Interaction')
disp('           M       SD      M       SD      M       SD      M       SD      F       df1  df2   p      eta_2     F      df1  df2    p      eta_2     F      df1  df2    p      eta_2')
disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i) m03(i) sd03(i) m04(i) sd04(i) F01(i)]) sprintf('%6.0f',[df1_01(i) df2_01(i)]) sprintf('%8.3f',p01(i)) sprintf('%8.3f',partial_eta_squared_within(i)) ...
    sprintf('%8.2f',F02(i)) sprintf('%6.0f',[df1_02(i) df2_02(i)]) sprintf('%8.3f',p02(i)) sprintf('%8.3f',partial_eta_squared_between(i)) ...
    sprintf('%8.2f',F03(i)) sprintf('%6.0f',[df1_03(i) df2_03(i)]) sprintf('%8.3f',p03(i)) sprintf('%8.3f',partial_eta_squared_interaction(i))] )
%% realism
par = [425   429   433   437   441   445   449   453];
raw_realism_Data=NaN(32,4);
k=0;
for i=1:4 % mean of 8 realism items
    raw_realism_Data(:,i)  = nanmean(sortdata(:,[par(1)+k par(2)+k par(3)+k par(4)+k par(5)+k par(6)+k par(7)+k par(8)+k]),2); % tested variable
    k=k+1;
end

par = [353 357 405 1000];
label = {'Sat   ' 'Use   ' 'Tor   ' 'RSM   '};
for i=1:size(par,2)
    index = par(i);
    if index < 1000
        if MM==2
            Data  = [nanmean(sortdata(:,[index index+1]),2); nanmean(sortdata(:,[index+2 index+3]),2)]; % Motion Off, On
        elseif MM==1
            Data  = [nanmean(sortdata(:,[index index+2]),2); nanmean(sortdata(:,[index+1 index+3]),2)]; % Linear, NonLinear
        end
    elseif index==1000
        if MM==2
            Data  = [nanmean(raw_realism_Data(:,[1 2]),2); nanmean(raw_realism_Data(:,[3 4]),2)]; % Motion Off, On
        elseif MM==1
            Data  = [nanmean(raw_realism_Data(:,[1 3]),2); nanmean(raw_realism_Data(:,[2 4]),2)]; % Linear, NonLinear
        end
    end
    
    Group = repmat( [ones(1,12) 2*ones(1,20);],1,2)'; % 1 = Truck driver, 2 = University driver
    SM    = [ones(32,1); 2*ones(32,1)]; % condition
    PPG  = repmat(1:32,1,2)'; % participant number
    X    = [Data Group SM PPG];
    X(isnan(X(:,1)),:)=[];
    X(:,1)=tiedrank(X(:,1));

    [~,p,~,stats]=ttest(X(X(:,2)==1 & X(:,3)==1,1),X(X(:,2)==1 & X(:,3)==2,1));TOp(i)=p;TOdf(i)=stats.df;TOt(i)=stats.tstat; % paired t test for truck drivers only
    [~,p,~,stats]=ttest(X(X(:,2)==2 & X(:,3)==1,1),X(X(:,2)==2 & X(:,3)==2,1));UOp(i)=p;UOdf(i)=stats.df;UOt(i)=stats.tstat; % paired t test for university drivers only
    [anova_SSQ,anova_df,anova_MSQ,anova_F,anova_p]=mixed_between_within_anova(X,1); % 1 = between-subjects factor, 2 = between-subjects factor, 3 = within-subjects factor, 4 = within x between interaction, 5 = within-subjects error
    
    partial_eta_squared_within(i)=cell2mat(anova_SSQ(3))/sum(cell2mat(anova_SSQ([3 5])));
    partial_eta_squared_interaction(i)=cell2mat(anova_SSQ(4))/sum(cell2mat(anova_SSQ([4 5])));
    partial_eta_squared_between(i)=cell2mat(anova_SSQ(1))/sum(cell2mat(anova_SSQ([1 2])));
    
    m01(i,:)  = nanmean(X( X(:,2)==1 & X(:,3)==1,1));
    sd01(i,:) = std(X(X(:,2)==1 & X(:,3)==1,1));
    m02(i,:)  = nanmean(X(X(:,2)==1 & X(:,3)==2,1));
    sd02(i,:) = std(X(X(:,2)==1 & X(:,3)==2,1));
    m03(i,:)  = nanmean(X( X(:,2)==2 & X(:,3)==1,1));
    sd03(i,:) = std(X(X(:,2)==2 & X(:,3)==1,1));
    m04(i,:)  = nanmean(X(X(:,2)==2 & X(:,3)==2,1));
    sd04(i,:) = std(X(X(:,2)==2 & X(:,3)==2,1));
    
    F01(i,:)    = cell2mat(anova_F(3));
    df1_01(i,:) = cell2mat(anova_df(3));
    df2_01(i,:) = cell2mat(anova_df(5));
    p01(i,:)    = cell2mat(anova_p(3));
    
    F02(i,:)    = cell2mat(anova_F(1));
    df1_02(i,:) = cell2mat(anova_df(1));
    df2_02(i,:) = cell2mat(anova_df(2));
    p02(i,:)    = cell2mat(anova_p(1));
    
    F03(i,:)    = cell2mat(anova_F(4));
    df1_03(i,:) = cell2mat(anova_df(4));
    df2_03(i,:) = cell2mat(anova_df(5));
    p03(i,:)    = cell2mat(anova_p(4));
    eta2(i+1,:)  = NaN;
end
%%
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i) m03(i) sd03(i) m04(i) sd04(i) F01(i)]) sprintf('%6.0f',[df1_01(i) df2_01(i)]) sprintf('%8.3f',p01(i)) sprintf('%8.3f',partial_eta_squared_within(i)) ...
        sprintf('%8.2f',F02(i)) sprintf('%6.0f',[df1_02(i) df2_02(i)]) sprintf('%8.3f',p02(i)) sprintf('%8.3f',partial_eta_squared_between(i)) ...
        sprintf('%8.2f',F03(i)) sprintf('%6.0f',[df1_03(i) df2_03(i)]) sprintf('%8.3f',p03(i)) sprintf('%8.3f',partial_eta_squared_interaction(i))] )
end
%%
disp(' ')
disp('Truck drivers only')
disp('Par      Truck_L         Truck_N         Effect of Condition      ')
disp('           M       SD      M       SD     df   p      t')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m01(i) sd01(i) m02(i) sd02(i)]) sprintf('%6.0f',TOdf(i))  sprintf('%8.3f',TOp(i)) ...
        sprintf('%8.2f',TOt(i)) ] )
end

disp(' ')
disp('University drivers only')
disp('Par      Truck_L         Truck_N         Effect of Condition      ')
disp('           M       SD      M       SD     df   p      t')
for i=1:size(par,2)
    disp([label{i} sprintf('%8.2f' ,[m03(i) sd03(i) m04(i) sd04(i)]) sprintf('%6.0f',UOdf(i))  sprintf('%8.3f',UOp(i)) ...
        sprintf('%8.2f',UOt(i)) ] )
end
%% Sickness
sickness_Group_TD_mean = nanmean(nanmean(sortdata(1:12,305:308),2));
sickness_Group_TD_std = nanstd(nanmean(sortdata(1:12,305:308),2));
sickness_Group_TD_N=length(nanmean(sortdata(1:12,305:308),2));

sickness_Group_UD_mean = nanmean(nanmean(sortdata(13:32,305:308),2));
sickness_Group_UD_std = nanstd(nanmean(sortdata(13:32,305:308),2));
sickness_Group_UD_N=length(nanmean(sortdata(13:32,305:308),2));

disp('Sickness Truck Drivers, mean, SD, N')
disp([sickness_Group_TD_mean sickness_Group_TD_std sickness_Group_TD_N])
disp('Sickness University Drivers, mean, SD')
disp([sickness_Group_UD_mean sickness_Group_UD_std sickness_Group_UD_N])

[~,p,~,stats]=ttest2(nanmean(sortdata(1:12,305:308),2),nanmean(sortdata(13:32,305:308),2));
disp('Sickness p-value')
disp(p)
disp('Sickness stats')
disp(stats)